# 线性代数

线性代数作为数学的一个分支，广泛应用于科学和工程中。

# 基础表示

## 标量（Scalar）

一个标量就是一个单独的数，它不同于线性代数中研究的其他大部分对象（通常是多个数的数组）。我们用斜体表示标量。标量通常被赋予小写的变量名称。当我们介绍标量时，会明确它们是哪种类型的数。

比如，在定义实数标量时，我们可能会说令 $s \in \mathbb{R}$ 表示一条线的斜率；在定义自然数标量时，我们可能会说令 $n \in \mathbb{N}$ 表示元素的数目。

## 向量（Vector）

一个向量是一列数，我们可以把向量看作空间中的点，每个元素是不同坐标轴上的坐标。这些数是有序排列的，通过次序中的索引，我们可以确定每个单独的数。通常我们赋予向量粗体的小写变量名称，比如 $\mathbf{x}$，也可以加上箭头 $\overrightarrow{\mathbf{x}}$。向量中的元素可以通过带脚标的斜体表示。向量 $\mathbf{x}$ 的第一个元素是 $\mathbf{x}_1$，第二个元素是 $\mathbf{x}_2$，等等。

我们也会注明存储在向量中的元素是什么类型的。如果每个元素都属于 $\mathbb{R}$，并且该向量有 $n$ 个元素，那么该向量属于实数集 $\mathbb{R}$ 的 $n$ 次笛卡尔乘积构成的集合，记为 $\mathbb{R}^n$。当需要明确表示向量中的元素时，我们会将元素排列成一个方括号包围的纵列：

$$
\boldsymbol{x}=\left[\begin{array}{c}{x_{1}} \\ {x_{2}} \\ {\vdots} \\ {x_{n}}\end{array}\right]

\\

\overrightarrow{\mathbf{x}}=\left(x_{1}, x_{2}, \cdots, x_{n}\right)^{T}=\left[\begin{array}{c}{x_{1}} \\ {x_{2}} \\ {\vdots} \\ {x_{n}}\end{array}\right]
$$

有时我们需要索引向量中的一些元素。在这种情况下，我们定义一个包含这些元素索引的集合，然后将该集合写在脚标处。比如，指定 $x_1$，$x_3$ 和 $x_6$，我们定义集合 $S=\{1,3,6\}$，然后写作 $x_S$。我们用符号 $-$ 表示集合的补集中的索引，比如 $x_{-1}$ 表示 $\mathbf{x}$ 中除 $x_1$ 外的所有元素，$x_{-S}$ 表示 $x$ 中除 $x_1$，$x_3$，$x_6$ 外所有元素构成的向量。

## 矩阵

矩阵是一个二维数组，其中的每一个元素被两个索引（而非一个）所确定。矩阵 $X \in \mathbb{R}^{m \times n}$ 可以表示为：

$$
X=\left[\begin{array}{cccc}{x_{1,1}} & {x_{1,2}} & {\cdots} & {x_{1, n}} \\ {x_{2,1}} & {x_{2,2}} & {\cdots} & {x_{2, n}} \\ {\vdots} & {\vdots} & {\ddots} & {\vdots} \\ {x_{m, 1}} & {x_{m, 2}} & {\cdots} & {x_{m, n}}\end{array}\right]
$$

简写为 $\left(x_{i, j}\right)_{m \times n}$ 或者 $\left[x_{i, j}\right]_{m \times n}$。

我们在表示矩阵中的元素时，通常以不加粗的斜体形式使用其名称，索引用逗号间隔。比如，$A_{1,1}$ 表示 $A$ 左上的元素，$A_{m,n}$ 表示 $A$ 右下的元素。通常可以使用 $:$ 来表示水平坐标，以表示垂直坐标 $i$ 中的所有元素。譬如 $A_{i,:}$ 表示 $A$ 垂直坐标 $i$ 上的一横排元素，也成为 A 的第 $i$ 行。同理，$A_{:,i}$ 表示 $A$ 的第 $i$ 列（Column）。

## 张量

在某些情况下，我们会讨论坐标超过两维的数组。一般地，一个数组中的元素分布在若干维坐标的规则网格中，我们称之为张量。张量往往用 $\mathbf{A}$ 来表示，坐标为 $i,j,k$ 的元素记为 $A_{i,j,k}$。
